Struct fuzion_std::fees::FeeReceiver
source · pub struct FeeReceiver {
pub address: Addr,
pub amount: Coin,
}Fields
address: Addramount: CoinTrait Implementations
sourceimpl Clone for FeeReceiver
impl Clone for FeeReceiver
sourcefn clone(&self) -> FeeReceiver
fn clone(&self) -> FeeReceiver
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for FeeReceiver
impl Debug for FeeReceiver
sourceimpl<'de> Deserialize<'de> for FeeReceiver
impl<'de> Deserialize<'de> for FeeReceiver
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for FeeReceiver
impl JsonSchema for FeeReceiver
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq for FeeReceiver
impl PartialEq for FeeReceiver
sourcefn eq(&self, other: &FeeReceiver) -> bool
fn eq(&self, other: &FeeReceiver) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for FeeReceiver
impl Serialize for FeeReceiver
impl StructuralPartialEq for FeeReceiver